@@ -19,30 +19,6 @@ has version => 2;
 
 sub E { JSON::Validator::Error->new(@_) }
 
-has generate_definitions_path => sub {
-  my $self = shift;
-  Scalar::Util::weaken($self);
-
-  return sub {
-    my $ref = shift;
-
-    if ($self->version eq '3') {
-
-      # Try to determine the path from the fqn
-      # We are only interested in the path in the fqn, so following fqn:
-      #
-      # #/components/schemas/some_schema, the returned path with be ['components', 'schemas']
-      my $path = Mojo::Path->new($ref->fqn =~ m!^.*#/(components/.+)$!)->to_dir->parts;
-      return $path->[0] ? $path : ['definitions'];
-    }
-    else {
-
-      # By default return definitions as path
-      return ['definitions'];
-    }
-  };
-};
-
 sub load_and_validate_schema {
   my ($self, $spec, $args) = @_;
 
@@ -253,6 +229,25 @@ sub _confess_invalid_in {
   confess "Unsupported \$in: $_[0]. Please report at https://github.com/jhthorsen/json-validator";
 }
 
+sub _definitions_path_for_ref {
+  my ($self, $ref) = @_;
+
+  if ($self->version eq '3') {
+
+    # Try to determine the path from the fqn
+    # We are only interested in the path in the fqn, so following fqn:
+    #
+    # #/components/schemas/some_schema, the returned path with be ['components', 'schemas']
+    my $path = Mojo::Path->new($ref->fqn =~ m!^.*#/(components/.+)$!)->to_dir->parts;
+    return $path->[0] ? $path : ['definitions'];
+  }
+  else {
+
+    # By default return definitions as path
+    return ['definitions'];
+  }
+}
+
 sub _get_request_data {
   my ($self, $c, $in) = @_;
 
@@ -668,10 +663,6 @@ OpenAPI schema.
 
 =back
 
-=head2 generate_definitions_path
-
-See L<JSON::Validator/generate_definitions_path>.
-
 =head2 validate_input
 
   @errors = $validator->validate_input($data, $schema);
